@@ -1,11 +1,12 @@
-my %parameter = ( path   => $m_hrSettings->{cgi}{bin} . '/templates',
-                  style  => $m_sStyle,
-                  title  => translate('help'),
-                  server => $m_hrSettings->{cgi}{serverName},
-                  id     => 'nlogin',
-                  class  => 'sidebar',
+my %parameter = (
+                 path   => $m_hrSettings->{cgi}{bin} . '/templates',
+                 style  => $m_sStyle,
+                 title  => translate('help'),
+                 server => $m_hrSettings->{cgi}{serverName},
+                 id     => 'nlogin',
+                 class  => 'sidebar',
 );
-my $window = new HTML::Window( \%parameter );
+my $window = new HTML::Window(\%parameter);
 $window->set_closeable(1);
 $window->set_moveable(1);
 $window->set_resizeable(0);
